### 1.17.0-rc1 (21.02.2024)

- Исправлена мультиязычность в модуле

### 1.16.0 (28.04.2023)

- Добавлено поле `css_class` в элемент меню

### 1.15.0 (17.03.2023)

- Предварительная выборка связей в `utils.get_menus`

### 1.14.0 (28.02.2023)

- `garpix_page` обновлен до версии 2.42.0.

### 1.14.0-rc1 (10.02.2023)

- `garpix_page` обновлен до версии 2.42.0-rc2.
- Добавлен параметр `subpage_url`
- Сериалайзер `MenuItemSerializer` изменен

### 1.13.0 (16.11.2022)

- Страница в админю.панели используется как `raw_id_fields`

### 1.12.0 - 1.12.1 (08.11.2022)

- Инстанс модели `MenuItem` добавлен в элементы меню контекстного процессора (ключ `object`)
- Метод `get_active_children` добавлен в модель `MenuItem`
- Добавлен сериалайзер `MenuItemWithChildrenSerializer`
- Значения `is_current` и `is_current_full` добавлены в `MenuItemSerializer

### 1.11.0 (12.09.2022)

- Добавлена возможность добавить ссылку на файл

### 1.10.0 (16.08.2022)

- Добавлен экшн клонирования в админ.панель
- Добавлена поддержка мультисайта в контекстном процессоре

### 1.9.0 (29.06.2022)

- Добавлена поддержка нескольких сайтов

### 1.8.0 (15.04.2022)

- Добавлена поддержка хеша в текущую страницу

### 1.7.0 (11.01.2022)

- Добюавлено поле `hash` в LinkMixin

### 1.6.1-1.6.2 (08.11.2021)

- Фикс бага с иконкой.

### 1.6.0 (29.10.2021)

- Добавлено поле icon
- Добавлена настройка `MENU_ICON_ALLOWED_TYPES`.
- Добавлена настройка `MENU_ICON_MAX_SIZE`.

### 1.5.1 (19.09.2021)

- Удалены элементы из model_to_dict :)

### 1.5.0 (19.09.2021)

- Добавлены `is_current` и `is_current_full`.

### 1.4.0 (19.09.2021)

- Утилиты для SPA меню.

### 1.3.0 (19.09.2021)

- Используется model_to_dict для menu_processor.

### 1.2.0 (18.09.2021)

- Добавлен `mixins.LinkMixin` (для `garpix_page` и внешних url).

### 1.1.0 (08.09.2021)

- Добавлена возможность фильтровать active_manager для модели MenuItem

### 1.0.2 (20.07.2021)

- Исправлен баг с `'NoneType' object has no attribute 'startswith'`.

### 1.0.1 (17.07.2021)

- Исправлен баг с`get_link()`.

### 1.0.0 (06.05.2021)

- Первый релиз в pypi.org.
